@@ -20,6 +20,7 @@ from reV.SAM.version_checker import PySamVersionChecker
 from reV.utilities.exceptions import (OutputWarning, ExecutionError,
                                       ParallelExecutionWarning,
                                       OffshoreWindInputWarning)
+from reV.utilities import log_versions
 
 from rex.resource import Resource
 from rex.utilities.execution import SpawnProcessPool
@@ -92,7 +93,7 @@ class BaseGen(ABC):
             results will be stored in-memory at any given time before flushing
             to disk.
         """
-
+        log_versions(logger)
         self._points_control = points_control
         self._year = None
         self._site_limit = None
@@ -247,7 +248,7 @@ class BaseGen(ABC):
         sam_configs : reV.config.sam.SAMGenConfig
             SAM config from the project points instance.
         """
-        return self.project_points.sam_configs
+        return self.project_points.sam_inputs
 
     @property
     def sam_metas(self):
@@ -494,8 +495,8 @@ class BaseGen(ABC):
         return ti
 
     @staticmethod
-    def _pp_to_pc(points, points_range, sam_files, tech, sites_per_worker=None,
-                  res_file=None, curtailment=None):
+    def _pp_to_pc(points, points_range, sam_configs, tech,
+                  sites_per_worker=None, res_file=None, curtailment=None):
         """
         Create ProjectControl from ProjectPoints
 
@@ -508,11 +509,11 @@ class BaseGen(ABC):
             Optional two-entry list specifying the index range of the sites to
             analyze. To be taken from the reV.config.PointsControl.split_range
             property.
-        sam_files : dict | str | list | SAMConfig
+        sam_configs : dict | str | SAMConfig
             SAM input configuration ID(s) and file path(s). Keys are the SAM
-            config ID(s), top level value is the SAM path. Can also be a single
-            config file str. If it's a list, it is mapped to the sorted list
-            of unique configs requested by points csv. Can also be a
+            config ID(s) which map to the config column in the project points
+            CSV. Values are either a JSON SAM config file or dictionary of SAM
+            config inputs. Can also be a single config file path or a
             pre loaded SAMConfig object.
         tech : str
             SAM technology to analyze (pvwattsv7, windpower, tcsmoltensalt,
@@ -539,10 +540,10 @@ class BaseGen(ABC):
         """
         if not isinstance(points, ProjectPoints):
             # make Project Points instance
-            pp = ProjectPoints(points, sam_files, tech=tech,
+            pp = ProjectPoints(points, sam_configs, tech=tech,
                                res_file=res_file, curtailment=curtailment)
         else:
-            pp = ProjectPoints(points.df, sam_files, tech=tech,
+            pp = ProjectPoints(points.df, sam_configs, tech=tech,
                                res_file=res_file, curtailment=curtailment)
 
         #  make Points Control instance
@@ -559,24 +560,27 @@ class BaseGen(ABC):
         return pc
 
     @classmethod
-    def get_pc(cls, points, points_range, sam_files, tech,
+    def get_pc(cls, points, points_range, sam_configs, tech,
                sites_per_worker=None, res_file=None, curtailment=None):
         """Get a PointsControl instance.
 
         Parameters
         ----------
-        points : slice | list | str | reV.config.project_points.PointsControl
-            Slice specifying project points, or string pointing to a project
-            points csv, or a fully instantiated PointsControl object.
+        points : slice | list | str | pandas.DataFrame
+                 | reV.config.project_points.PointsControl
+            Slice or list specifying project points,
+            or string pointing to a project points csv,
+            or a pre-loaded project points DataFrame,
+            or a fully instantiated PointsControl object.
         points_range : list | None
             Optional two-entry list specifying the index range of the sites to
             analyze. To be taken from the reV.config.PointsControl.split_range
             property.
-        sam_files : dict | str | list | SAMConfig
+        sam_configs : dict | str | SAMConfig
             SAM input configuration ID(s) and file path(s). Keys are the SAM
-            config ID(s), top level value is the SAM path. Can also be a single
-            config file str. If it's a list, it is mapped to the sorted list
-            of unique configs requested by points csv. Can also be a
+            config ID(s) which map to the config column in the project points
+            CSV. Values are either a JSON SAM config file or dictionary of SAM
+            config inputs. Can also be a single config file path or a
             pre loaded SAMConfig object.
         tech : str
             SAM technology to analyze (pvwattsv7, windpower, tcsmoltensalt,
@@ -616,17 +620,13 @@ class BaseGen(ABC):
         logger.debug('Sites per worker being set to {} for Gen/Econ '
                      'PointsControl.'.format(sites_per_worker))
 
-        if isinstance(points, (slice, list, str, ProjectPoints)):
-            pc = cls._pp_to_pc(points, points_range, sam_files, tech,
-                               sites_per_worker=sites_per_worker,
-                               res_file=res_file, curtailment=curtailment)
-
-        elif isinstance(points, PointsControl):
+        if isinstance(points, PointsControl):
             # received a pre-intialized instance of pointscontrol
             pc = points
         else:
-            raise TypeError('Points input type is unrecognized: '
-                            '"{}"'.format(type(points)))
+            pc = cls._pp_to_pc(points, points_range, sam_configs, tech,
+                               sites_per_worker=sites_per_worker,
+                               res_file=res_file, curtailment=curtailment)
 
         return pc
 
@@ -843,7 +843,7 @@ class BaseGen(ABC):
 
         elif dset in self.project_points.all_sam_input_keys:
             data_shape = (n_sites, )
-            data = list(self.project_points.sam_configs.values())[0][dset]
+            data = list(self.project_points.sam_inputs.values())[0][dset]
             if isinstance(data, (list, tuple, np.ndarray, str)):
                 msg = ('Cannot pass through non-scalar SAM input key "{}" '
                        'as an output_request!'.format(dset))
@@ -990,7 +990,7 @@ class BaseGen(ABC):
 
     def _check_sam_version_inputs(self):
         """Check the PySAM version and input keys. Fix where necessary."""
-        for key, parameters in self.project_points.sam_configs.items():
+        for key, parameters in self.project_points.sam_inputs.items():
             updated = PySamVersionChecker.run(self.tech, parameters)
             sam_obj = self._points_control._project_points._sam_config_obj
             sam_obj._inputs[key] = updated
