@@ -87,7 +87,8 @@ def from_config(ctx, config_file, verbose):
         os.makedirs(config.dirout)
 
     # initialize loggers.
-    init_mult(name, config.logdir, modules=['reV', 'rex'], verbose=verbose)
+    init_mult(name, config.logdir, modules=[__name__, 'reV', 'rex'],
+              verbose=verbose)
 
     # Initial log statements
     logger.info('Running reV Generation from config file: "{}"'
@@ -414,7 +415,7 @@ def local(ctx, max_workers, timeout, points_range, verbose):
     verbose = any([verbose, ctx.obj['VERBOSE']])
 
     # initialize loggers for multiple modules
-    init_mult(name, logdir, modules=['reV', 'rex'],
+    init_mult(name, logdir, modules=[__name__, 'reV', 'rex'],
               verbose=verbose, node=True)
 
     for key, val in ctx.obj.items():
@@ -429,10 +430,10 @@ def local(ctx, max_workers, timeout, points_range, verbose):
     points = _parse_points(ctx)
 
     # Execute the Generation module with smart data flushing.
-    Gen.reV_run(tech=tech,
-                points=points,
-                sam_files=sam_files,
-                res_file=res_file,
+    Gen.reV_run(tech,
+                points,
+                sam_files,
+                res_file,
                 site_data=site_data,
                 output_request=output_request,
                 curtailment=curtailment,
