@@ -18,7 +18,7 @@ from reV import __version__
 
 from rex.utilities.hpc import SLURM
 from rex.utilities.cli_dtypes import (STR, INT, FLOAT, STRLIST, FLOATLIST,
-                                      STRFLOAT)
+                                      STRFLOAT, STR_OR_LIST)
 from rex.utilities.loggers import init_mult
 from rex.utilities.utilities import dict_str_load, get_class_properties
 
@@ -169,8 +169,9 @@ def from_config(ctx, config_file, verbose):
 
 
 @main.group(invoke_without_command=True)
-@click.option('--excl_fpath', '-exf', type=STR, required=True,
-              help='Exclusions file (.h5).')
+@click.option('--excl_fpath', '-exf', type=STR_OR_LIST, required=True,
+              help='Single exclusions file (.h5) or a '
+              'list of exclusion files (.h5, .h5).')
 @click.option('--gen_fpath', '-gf', type=STR, required=True,
               help='reV generation/econ output file.')
 @click.option('--tm_dset', '-tm', type=STR, required=True,
@@ -285,6 +286,7 @@ def direct(ctx, excl_fpath, gen_fpath, tm_dset, econ_fpath, res_fpath,
            friction_dset, cap_cost_scale, out_dir, max_workers,
            sites_per_worker, log_dir, pre_extract_inclusions, verbose):
     """reV Supply Curve Aggregation Summary CLI."""
+    sites_per_worker = sites_per_worker if sites_per_worker else 100
 
     name = ctx.obj['NAME']
     ctx.obj['EXCL_FPATH'] = excl_fpath
@@ -319,10 +321,22 @@ def direct(ctx, excl_fpath, gen_fpath, tm_dset, econ_fpath, res_fpath,
         init_mult(name, log_dir, modules=[__name__, 'reV', 'rex'],
                   verbose=verbose)
 
-        with h5py.File(excl_fpath, mode='r') as f:
-            dsets = list(f)
+        dsets = []
+        paths = excl_fpath
+        if isinstance(excl_fpath, str):
+            paths = [excl_fpath]
+        for fp in paths:
+            with h5py.File(fp, mode='r') as f:
+                dsets += list(f)
+
         if tm_dset in dsets:
             logger.info('Found techmap "{}".'.format(tm_dset))
+        elif tm_dset not in dsets and not isinstance(excl_fpath, str):
+            msg = ('Could not find techmap dataset "{}" and cannot run '
+                   'techmap with arbitrary multiple exclusion filepaths '
+                   'to write to: {}'.format(tm_dset, excl_fpath))
+            logger.error(msg)
+            raise RuntimeError(msg)
         else:
             logger.info('Could not find techmap "{}". Running techmap module.'
                         .format(tm_dset))
