@@ -76,7 +76,8 @@ def from_config(ctx, config_file, verbose):
         verbose = True
 
     # initialize loggers
-    init_mult(name, config.logdir, modules=['reV', 'rex'], verbose=verbose)
+    init_mult(name, config.logdir, modules=[__name__, 'reV', 'rex'],
+              verbose=verbose)
 
     # Initial log statements
     logger.info('Running reV supply curve from config '
@@ -105,7 +106,7 @@ def from_config(ctx, config_file, verbose):
                        wind_dirs=config.wind_dirs,
                        n_dirs=config.n_dirs,
                        downwind=config.downwind,
-                       max_workers=config.max_workers,
+                       max_workers=config.execution_control.max_workers,
                        out_dir=config.dirout,
                        log_dir=config.logdir,
                        simple=config.simple,
@@ -126,7 +127,7 @@ def from_config(ctx, config_file, verbose):
         ctx.obj['N_DIRS'] = config.n_dirs
         ctx.obj['DOWNWIND'] = config.downwind
         ctx.obj['OFFSHORE_COMPETE'] = config.offshore_compete
-        ctx.obj['MAX_WORKERS'] = config.max_workers
+        ctx.obj['MAX_WORKERS'] = config.execution_control.max_workers
         ctx.obj['OUT_DIR'] = config.dirout
         ctx.obj['LOG_DIR'] = config.logdir
         ctx.obj['SIMPLE'] = config.simple
@@ -223,7 +224,7 @@ def direct(ctx, sc_points, trans_table, fixed_charge_rate, sc_features,
 
     if ctx.invoked_subcommand is None:
         t0 = time.time()
-        init_mult(name, log_dir, modules=['reV', 'rex'],
+        init_mult(name, log_dir, modules=[__name__, 'reV', 'rex'],
                   verbose=verbose)
 
         if isinstance(transmission_costs, str):
